@@ -22,5 +22,9 @@ print """M30W Copyright (C) 2012 M30W developers.
 from M30W.debug import debug
 from M30W.GUI import show_app
 
-debug("Starting GUI...", 1)
-show_app()
+def main():
+    debug("Starting GUI...", 1)
+    show_app()
+
+if __name__ == '__main__':
+    main()
\ No newline at end of file
